/*
 * FabMotorController.h v0.1
 * A library to control through I2C the FabMotorController, 
 * a hardware based on the ATTINY1614 and the L298N driver.
 * 
 * Author: Harley Lara
 * Create: 01 May 2021
 * License: (CC BY-SA 4.0) Attribution-ShareAlike 4.0 International
 * 
 * This work may be reproduced, modified, distributed,
 * performed, and displayed for any purpose, but must
 * acknowledge this project. Copyright is retained and
 * must be preserved. The work is provided as is; no
 * warranty is provided, and users accept all liability.
 * 
 */

#ifndef _FABMOTORCONTROLLER_
#define _FABMOTORCONTROLLER_

#include <Arduino.h>

// Output identifiers
#define OUTPUT1 1
#define OUTPUT2 2

class FabMotorController{
  private:
    /******** Dirección de las salidas ********/
    // 1: Forward
    // 0: Backward
    bool _OUT1_direction = 1;
    bool _OUT2_direction = 1;
    
    /******** Initial speed of the motors ********/
    // _speed1 from 0 to 100;
    unsigned char _speed1 = 0;
    // _speed2 from 0 to 100;
    unsigned char _speed2 = 0;
  
    // I2C Controller address
    unsigned char _addr = 0x04;
  
  public:
    // Initializes the I2C with a default I2C address (0x04)
    int begin(unsigned char addr);

    /********  Activates the output at a given speed ********/
    // output: OUTPUT1, OUTPUT2
    // _speed: from -100 to 100, 
    //         where _speed greater than zero moves the motor clockwise 
    //         (the direction of the motor depends on the physical connection 
    //         of the motor, if it turns counterclockwise it is necessary to 
    //         reverse the connection).
    void run(unsigned char output, int _speed);

    /******** Stops the given output by locking for 100ms the motor rotation and then releases the motor lock ********/
    // output: OUTPUT1, OUTPUT2
    void stop(unsigned char output);

    /******** Stops motor rotation allowing it to run freely (no motor blocking) ********/
    void stopLock(unsigned char output);

    bool isMoving(unsigned char output);
};
#endif
